"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Config = void 0;
const yargs_1 = __importDefault(require("yargs"));
const _enums_1 = require("./@enums");
const configBuilder_1 = require("./configBuilder");
const defaults_1 = require("./constants/defaults");
const projectTypes = Object.keys(_enums_1.ProjectType);
const args = yargs_1.default
    .option('url', {
    describe: 'GitHub repo url (https or ssh)',
    type: 'string',
    demandOption: true,
})
    .option('pr', {
    describe: 'PR number',
    type: 'number',
    demandOption: true,
})
    .option('token', {
    describe: 'GitHub token',
    type: 'string',
    demandOption: true,
})
    .option('buildLogFile', {
    alias: 'f',
    describe: `Build log content files formatted in '<type>;<path>[;<cwd>]'
where <type> is one of [${projectTypes.join(', ')}]
<path> is build log file path to be processed
and <cwd> is build root directory (optional (Will use current context as cwd)).
`,
    type: 'array',
    string: true,
    number: false,
    demandOption: true,
})
    .coerce('buildLogFile', (files) => {
    return files.map((opt) => {
        const [type, path, cwd] = opt.split(';');
        if (!projectTypes.includes(type) || !path)
            return null;
        return { type, path, cwd: cwd !== null && cwd !== void 0 ? cwd : process.cwd() };
    });
})
    .option('output', {
    alias: 'o',
    describe: 'Output parsed log file',
    type: 'string',
    default: defaults_1.DEFAULT_OUTPUT_FILE,
})
    .option('removeOldComment', {
    type: 'boolean',
    describe: 'Remove existing CodeCoach comments before putting new one',
    default: false,
})
    .check((options) => {
    if (!options.pr || Array.isArray(options.pr))
        throw '--pr config should be a single number';
    if (!options.buildLogFile || options.buildLogFile.some((file) => file === null))
        throw 'all of `--buildLogFile` options should have correct format';
    return true;
})
    .help()
    .wrap(120)
    .parse(process.argv.slice(1));
exports.Config = Object.freeze({
    app: configBuilder_1.buildAppConfig(args),
    provider: configBuilder_1.buildProviderConfig(args),
});
