"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AndroidLintStyleParser = void 0;
const Logger_1 = require("../Logger");
const log_severity_enum_1 = require("./@enums/log.severity.enum");
const parser_interface_1 = require("./@interfaces/parser.interface");
const xml_js_1 = require("xml-js");
class AndroidLintStyleParser extends parser_interface_1.Parser {
    parse(content) {
        var _a, _b, _c;
        try {
            if (!content)
                return [];
            return ((_c = (_b = (_a = AndroidLintStyleParser.xmlToLog(content).issues[0]) === null || _a === void 0 ? void 0 : _a.issue) === null || _b === void 0 ? void 0 : _b.flatMap((issue) => {
                return AndroidLintStyleParser.toLog(issue, issue.location[0]);
            })) !== null && _c !== void 0 ? _c : []);
        }
        catch (err) {
            Logger_1.Log.warn('AndroidStyle Parser: parse with content error', content);
            throw err;
        }
    }
    static toLog(issue, location) {
        return {
            log: issue._attributes.errorLine1.trim(),
            line: location._attributes.line,
            lineOffset: location._attributes.column,
            msg: issue._attributes.message,
            source: location._attributes.file,
            severity: AndroidLintStyleParser.getSeverity(issue._attributes.severity.toLowerCase()),
            valid: true,
        };
    }
    static getSeverity(levelText) {
        switch (levelText) {
            case 'info':
                return log_severity_enum_1.LogSeverity.info;
            case 'warning':
                return log_severity_enum_1.LogSeverity.warning;
            case 'error':
                return log_severity_enum_1.LogSeverity.error;
            default:
                return log_severity_enum_1.LogSeverity.unknown;
        }
    }
    static xmlToLog(xmlContent) {
        return xml_js_1.xml2js(xmlContent, convertOption);
    }
}
exports.AndroidLintStyleParser = AndroidLintStyleParser;
const convertOption = {
    compact: true,
    nativeType: true,
    nativeTypeAttributes: true,
    alwaysArray: true,
};
