"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DartLintParser = void 0;
const parser_interface_1 = require("./@interfaces/parser.interface");
const log_severity_enum_1 = require("./@enums/log.severity.enum");
const lineBreak_util_1 = require("./utils/lineBreak.util");
class DartLintParser extends parser_interface_1.Parser {
    parse(content) {
        return lineBreak_util_1.splitByLine(content)
            .map((line) => DartLintParser.lineToLog(line))
            .filter((f) => f != DartLintParser.emptyLog);
    }
    static lineToLog(line) {
        const lineMatch = line.match(/^(.*) • (.*) • (.*):(\d+):(\d+) • (.*)/);
        return lineMatch ? DartLintParser.lineMatchToLog(lineMatch) : DartLintParser.emptyLog;
    }
    static lineMatchToLog(lineMatch) {
        const [, severityText, message, source, line, offset, log] = lineMatch;
        return {
            log: log,
            line: Number(line),
            lineOffset: Number(offset),
            msg: message,
            source: source,
            severity: DartLintParser.stringToSeverity(severityText),
            valid: true,
        };
    }
    static stringToSeverity(levelText) {
        switch (levelText) {
            case 'error':
                return log_severity_enum_1.LogSeverity.error;
            case 'warning':
                return log_severity_enum_1.LogSeverity.warning;
            case 'info':
                return log_severity_enum_1.LogSeverity.info;
            default:
                return log_severity_enum_1.LogSeverity.unknown;
        }
    }
}
exports.DartLintParser = DartLintParser;
DartLintParser.emptyLog = {
    log: '',
    msg: '',
    severity: log_severity_enum_1.LogSeverity.unknown,
    source: '',
    valid: false,
};
