"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.DotnetBuildParser = void 0;
const path_1 = require("path");
const slash_1 = __importDefault(require("slash"));
const Logger_1 = require("../Logger");
const path_util_1 = require("../Provider/utils/path.util");
const parser_interface_1 = require("./@interfaces/parser.interface");
const dotnetSeverityMap_1 = require("./utils/dotnetSeverityMap");
const lineBreak_util_1 = require("./utils/lineBreak.util");
class DotnetBuildParser extends parser_interface_1.Parser {
    parse(content) {
        return lineBreak_util_1.splitByLine(content)
            .map((log) => this.toLog(log))
            .filter((log) => log);
    }
    toLog(log) {
        const structureMatch = log.match(/>([^\s()]+)(?:\((\d+),(\d+)\))?\s*:\s*(\w+)\s*(\w+)\s*:\s*([^\[]+)(?:\[(.+)])?$/);
        if (!structureMatch) {
            const message = "DotnetBuildParser Error: log structure doesn't match";
            Logger_1.Log.error(message, { log });
            throw new Error(message);
        }
        const [, src, _line, _lineOffset, severityText, errorCode, content, _csproj,] = structureMatch;
        const relativeSrcPath = path_util_1.getRelativePath(this.cwd, src);
        if (!relativeSrcPath) {
            Logger_1.Log.warn(`DotnetBuildParser Error: source path is not a relative to root`, {
                src,
            });
        }
        return {
            log,
            line: Number(_line),
            lineOffset: Number(_lineOffset),
            msg: `${errorCode.trim()}: ${content.trim()}`,
            source: relativeSrcPath !== null && relativeSrcPath !== void 0 ? relativeSrcPath : path_1.basename(slash_1.default(_csproj)),
            severity: dotnetSeverityMap_1.mapSeverity(severityText),
            valid: !!relativeSrcPath,
        };
    }
}
exports.DotnetBuildParser = DotnetBuildParser;
