"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ESLintParser = void 0;
const Logger_1 = require("../Logger");
const path_util_1 = require("../Provider/utils/path.util");
const log_severity_enum_1 = require("./@enums/log.severity.enum");
const parser_interface_1 = require("./@interfaces/parser.interface");
class ESLintParser extends parser_interface_1.Parser {
    parse(content) {
        try {
            if (!content)
                return [];
            const logs = JSON.parse(content);
            return logs
                .filter((log) => log.messages.length !== 0)
                .flatMap((log) => {
                const source = path_util_1.getRelativePath(this.cwd, log.filePath);
                return log.messages.map((msg) => ESLintParser.toLog(msg, source));
            });
        }
        catch (err) {
            Logger_1.Log.warn('ESLint Parser: parse with content via JSON error', content);
            throw err;
        }
    }
    static toLog(log, source) {
        return {
            log: JSON.stringify(log),
            line: log.line + 1,
            lineOffset: log.column,
            msg: log.message,
            source: source !== null && source !== void 0 ? source : '',
            severity: ESLintParser.getSeverity(log.severity),
            valid: source !== null,
        };
    }
    static getSeverity(esLevel) {
        switch (esLevel) {
            case 0:
                return log_severity_enum_1.LogSeverity.ignore;
            case 1:
                return log_severity_enum_1.LogSeverity.warning;
            case 2:
                return log_severity_enum_1.LogSeverity.error;
            default:
                return log_severity_enum_1.LogSeverity.unknown;
        }
    }
}
exports.ESLintParser = ESLintParser;
