"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MSBuildParser = void 0;
const path_1 = require("path");
const slash_1 = __importDefault(require("slash"));
const Logger_1 = require("../Logger");
const path_util_1 = require("../Provider/utils/path.util");
const parser_interface_1 = require("./@interfaces/parser.interface");
const dotnetSeverityMap_1 = require("./utils/dotnetSeverityMap");
const lineBreak_util_1 = require("./utils/lineBreak.util");
class MSBuildParser extends parser_interface_1.Parser {
    parse(content) {
        return lineBreak_util_1.splitByLine(content)
            .map((log) => this.toLog(log))
            .filter((log) => log);
    }
    toLog(log) {
        const structureMatch = log.match(/^(.+)(?:\((\d+),(\d+)\)): (\w+) (\w+): ([^\[]+)(?:\[(.+)])?$/);
        if (!structureMatch) {
            const message = "MSBuildParser Error: log structure doesn't match";
            Logger_1.Log.error(message, { log });
            throw new Error(message);
        }
        const [, _filepath, _line, _lineOffset, severityText, code, content, _csprojFullPath,] = structureMatch;
        const fileFullPath = slash_1.default(path_1.join(slash_1.default(_csprojFullPath), '..', slash_1.default(_filepath)));
        const fileRelativePath = path_util_1.getRelativePath(this.cwd, fileFullPath);
        return {
            log,
            line: Number(_line),
            lineOffset: Number(_lineOffset),
            msg: `${code.trim()}: ${content.trim()}`,
            source: fileRelativePath !== null && fileRelativePath !== void 0 ? fileRelativePath : fileFullPath,
            severity: dotnetSeverityMap_1.mapSeverity(severityText),
            valid: fileRelativePath !== null,
        };
    }
}
exports.MSBuildParser = MSBuildParser;
