"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ScalaStyleParser = void 0;
const Logger_1 = require("../Logger");
const path_util_1 = require("../Provider/utils/path.util");
const log_severity_enum_1 = require("./@enums/log.severity.enum");
const parser_interface_1 = require("./@interfaces/parser.interface");
const xml_js_1 = require("xml-js");
class ScalaStyleParser extends parser_interface_1.Parser {
    parse(content) {
        var _a, _b, _c;
        try {
            if (!content)
                return [];
            const convertOption = {
                compact: true,
                nativeType: true,
                nativeTypeAttributes: true,
                alwaysArray: true,
            };
            const rawError = content
                .split(`\n`)
                .map((line) => line.trim())
                .filter((line) => line.slice(0, 6) === '<error');
            const parsedContent = xml_js_1.xml2js(content, convertOption);
            let rawIndex = 0;
            return ((_c = (_b = (_a = parsedContent.checkstyle[0]) === null || _a === void 0 ? void 0 : _a.file) === null || _b === void 0 ? void 0 : _b.flatMap((f) => {
                const source = path_util_1.getRelativePath(this.cwd, f._attributes.name);
                return f.error.map((log) => ScalaStyleParser.toLog(log, source, rawError[rawIndex++]));
            })) !== null && _c !== void 0 ? _c : []);
        }
        catch (err) {
            Logger_1.Log.warn('ScalaStyle Parser: parse with content error', content);
            throw err;
        }
    }
    static toLog(log, source, raw) {
        var _a;
        return {
            log: raw !== null && raw !== void 0 ? raw : '',
            line: (_a = log._attributes.line) !== null && _a !== void 0 ? _a : undefined,
            lineOffset: log._attributes.column,
            msg: log._attributes.message,
            source: source !== null && source !== void 0 ? source : '',
            severity: ScalaStyleParser.getSeverity(log._attributes.severity),
            valid: source !== null,
        };
    }
    static getSeverity(ScalaStyleLevel) {
        switch (ScalaStyleLevel) {
            case 'info':
                return log_severity_enum_1.LogSeverity.info;
            case 'warning':
                return log_severity_enum_1.LogSeverity.warning;
            case 'error':
                return log_severity_enum_1.LogSeverity.error;
            default:
                return log_severity_enum_1.LogSeverity.unknown;
        }
    }
}
exports.ScalaStyleParser = ScalaStyleParser;
