"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TSLintParser = void 0;
const Logger_1 = require("../Logger");
const path_util_1 = require("../Provider/utils/path.util");
const parser_interface_1 = require("./@interfaces/parser.interface");
class TSLintParser extends parser_interface_1.Parser {
    parse(content) {
        try {
            if (!content)
                return [];
            const logsJson = JSON.parse(content);
            return logsJson.map((el) => this.toLog(el));
        }
        catch (err) {
            Logger_1.Log.warn('TSLint Parser: parse with content via JSON error', content);
            throw err;
        }
    }
    toLog(log) {
        const parsed = {
            log: JSON.stringify(log),
            line: log.startPosition.line + 1,
            lineOffset: log.startPosition.character,
            // there are no code portion present in tslint output
            msg: log.failure,
            source: '',
            severity: log.ruleSeverity.toLowerCase(),
            valid: true,
        };
        const source = path_util_1.getRelativePath(this.cwd, log.name);
        if (!source)
            return Object.assign(Object.assign({}, parsed), { valid: false });
        return Object.assign(Object.assign({}, parsed), { source });
    }
}
exports.TSLintParser = TSLintParser;
