"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MessageUtil = void 0;
const Parser_1 = require("../../Parser");
const EMOJI_ERROR = ':rotating_light:';
const EMOJI_WARNING = ':warning:';
class MessageUtil {
    static createMessageWithEmoji(msg, severity) {
        let emoji = '';
        switch (severity) {
            case Parser_1.LogSeverity.error:
                emoji = EMOJI_ERROR;
                break;
            case Parser_1.LogSeverity.warning:
                emoji = EMOJI_WARNING;
                break;
        }
        return `${emoji} ${msg}`;
    }
    static generateOverviewMessage(nOfErrors, nOfWarnings) {
        if (nOfErrors + nOfWarnings === 0) {
            return '## CodeCoach reports no issue, good job';
        }
        const issueCountMsg = this.pluralize('issue', nOfErrors + nOfWarnings);
        const errorMsg = MessageUtil.createMessageWithEmoji(MessageUtil.pluralize('error', nOfErrors), Parser_1.LogSeverity.error);
        const warningMsg = MessageUtil.createMessageWithEmoji(MessageUtil.pluralize('warning', nOfWarnings), Parser_1.LogSeverity.warning);
        return `## CodeCoach reports ${issueCountMsg}
${errorMsg}
${warningMsg}`;
    }
    static createOtherIssueReport(logs) {
        if (logs.length === 0)
            return null;
        const issuesTableContent = logs.map((l) => `| ${l.source} | ${l.msg} |`).join('\n');
        // Blank line required after </summary> to let markdown after it display correctly
        return `<details>
<summary><span>By the way, there are other issues those might not related to your code</span></summary>

| source | message |
|-|-|
${issuesTableContent}
</details>`;
    }
    static pluralize(word, n) {
        const fill = word.split('').shift() === 's' ? 'es' : 's';
        return n + ' ' + (n > 1 ? `${word}${fill}` : word);
    }
    static generateCommitDescription(nOfErrors) {
        return nOfErrors
            ? `CodeCoach report ${nOfErrors} errors`
            : 'CodeCoach report no critical issue, good job!';
    }
}
exports.MessageUtil = MessageUtil;
