"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPatch = void 0;
function getPatch(patch) {
    if (!patch)
        return [];
    const touchLines = [];
    const splitter = /\n(?=@@)/g;
    const diffInfoMatcher = /@@ -\d+(?:,\d+)? \+(\d+)(?:,\d+)? @@/;
    const diffs = patch.split(splitter);
    diffs.forEach((diff) => {
        const [diffInfo, ...content] = diff.split('\n');
        const diffMatch = diffInfo.match(diffInfoMatcher);
        if (!diffMatch)
            return;
        const [, _from] = diffMatch;
        if (_from === '0')
            return;
        const from = Number.parseInt(_from);
        const addedLines = content.filter((line) => line[0] !== '-');
        touchLines.push(...getPatchSingleSection(addedLines, from));
    });
    return touchLines;
}
exports.getPatch = getPatch;
function getPatchSingleSection(lines, from) {
    return lines.reduce((patches, line, index) => {
        var _a;
        if (line[0] !== '+')
            return patches;
        const currentLine = from + index;
        const lastPatch = patches.slice(-1).pop();
        if ((lastPatch === null || lastPatch === void 0 ? void 0 : lastPatch.to) !== currentLine - 1) {
            return patches.concat({ from: currentLine, to: currentLine });
        }
        return patches
            .slice(0, -1)
            .concat({ from: (_a = lastPatch === null || lastPatch === void 0 ? void 0 : lastPatch.from) !== null && _a !== void 0 ? _a : currentLine, to: currentLine });
    }, []);
}
